/**
 * Kivu4j. Copyright (C) 2010 . see<http://kivu4j.sourceforge.net />

   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses />.
 */

package net.sourceforge.kivu4j.utils.job;

import org.quartz.JobExecutionContext;
import org.quartz.JobExecutionException;
import org.quartz.SchedulerContext;
import org.quartz.SchedulerException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.context.ApplicationContext;
import org.springframework.scheduling.quartz.QuartzJobBean;

/**
 * 抽象的泛型任务。
 * 
 * <p>
 * 这个类只是任务的定义，真正任务的处理过程是{@link AbstractProcessor}类实现的。
 * </p>
 * 
 * 
 * @author Lucky Yang
 * @see org.springframework.scheduling.quartz.QuartzJobBean
 * @see AbstractProcessor
 */
public abstract class AbstractJob<P extends AbstractProcessor> extends QuartzJobBean{
	protected Logger logger = LoggerFactory.getLogger(getClass());
	
	@Override
	protected void executeInternal(JobExecutionContext context)
			throws JobExecutionException {
		try{
			SchedulerContext schedulerContext = context.getScheduler().getContext();
			ApplicationContext applicationContext = (ApplicationContext) schedulerContext.get("applicationContext");
			AbstractProcessor processor = applicationContext.getBean(this.getJobProcessor());

			processor.process(context);
		}catch (SchedulerException e) {
			throw new JobExecutionException(e);
		}
	}

	protected abstract Class<P> getJobProcessor();
	

}
