/**
 * Kivu4j. Copyright (C) 2010 . see<http://kivu4j.sourceforge.net />

   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses />.
 */

package net.sourceforge.kivu4j.utils.job;

import java.io.Serializable;
import java.util.Collection;

import net.sourceforge.kivu4j.utils.lang.domain.NameValue;

import org.quartz.JobDetail;
import org.quartz.Trigger;



/**
 * 管理器控制
 *
 * @author Lucky Yang
 */
public interface ScheduleManager extends Serializable{
	/**
	 * 注销任务。注销后，任务将无法运行或激活
	 * 
	 * @param triggerName
	 * @param triggerGroup
	 */
	void unscheduleJob(String triggerName, String triggerGroup);

	/**
	 * 任务名称的列表
	 * 
	 * @param jobGroup
	 * @return
	 */
	String[] getJobNames(String jobGroup);

	/**
	 * 特定任务的所有触发器
	 * 
	 * @param jobName
	 * @param jobGroup
	 * @return
	 */
	Trigger[] getTriggersOfJob(String jobName, String jobGroup);

	/**
	 * 注册一个任务的触发器,需要判断修改时间
	 * 
	 * @param oldTrg
	 * @param newTrigger
	 */
	void rescheduleJob(Trigger oldTrg, Trigger newTrigger);

	/**
	 * 得到特定的任务信息
	 * 
	 * @param name
	 * @param group
	 * @return
	 */
	JobDetail getJobDetail(String name, String group);

	/**
	 * 得到特定的触发器信息
	 * 
	 * @param name
	 * @param group
	 * @return
	 */
	Trigger getTrigger(String name, String group);

	/**
	 * 注册一个任务
	 * 
	 * @param newTrigger
	 */
	void scheduleJob(Trigger newTrigger);

	/**
	 * 管理器元数据
	 * 
	 * @return
	 */
	Collection<NameValue> getMetaData();

	/**
	 * 激活所有任务
	 */
	void resumeAll();

	/**
	 * 暂停所有任务
	 */
	void pauseAll();

	/**
	 * 关闭管理器
	 */
	void shutdown();

	/**
	 * 启动管理器
	 */
	void startup();

	/**
	 * 暂停管理器
	 */
	void standby();

	/**
	 * 激活管理器
	 */
	void active();

	/**
	 * 触发器状态
	 * 
	 * @param name
	 * @param group
	 * @return
	 */
	int getTriggerState(String name, String group);

	/**
	 * 激活trigger
	 * 
	 * @param name
	 * @param group
	 */
	void resumeTrigger(String name, String group);

	/**
	 * 暂停trigger
	 * 
	 * @param name
	 * @param group
	 */	
	void pauseTrigger(String name, String group);

	/**
	 * 激活group
	 * 
	 * @param group
	 */
	void resumeGroup(String group);

	/**
	 * 暂停group
	 * 
	 * @param group
	 */	
	void pauseGroup(String group);


	/**
	 * 创建一个job
	 * 
	 * @param name
	 * @param group
	 * @param description
	 * @param clazz
	 * @return
	 */
	JobDetail createJob(String name, String group, String description,
			Class<?> clazz);

	/**
	 * 发布一个job
	 * 
	 * @param job
	 */
	void addJob(JobDetail job);

	/**
	 * 发布一个job,如果不存在此job。
	 * 
	 * @param name
	 * @param group
	 * @param clazz
	 * @param description
	 */
	void addJob(String name, String group, Class<?> clazz, String description);

	/**
	 * 是否standby状态
	 * 
	 * @return
	 */
	boolean isStandby();

}
